==> qtjambi-sensors-6.5.7-sources.jar: io/qt/sensors/QMagnetometer.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qmagnetometer.html">QMagnetometer</a></code></p>
 */
public class QMagnetometer extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMagnetometer.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometer.html#returnGeoValues-prop">QMagnetometer::<wbr/>returnGeoValuesChanged(bool)</a></code></p>
     */
    @QtPropertyNotify(name="returnGeoValues")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Boolean> returnGeoValuesChanged = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometer.html#QMagnetometer">QMagnetometer::<wbr/>QMagnetometer(QObject*)</a></code></p>
     */
    public QMagnetometer(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMagnetometer instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr/>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QMagnetometerReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QMagnetometerReading reading_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometer.html#returnGeoValues-prop">QMagnetometer::<wbr/>returnGeoValues()const</a></code></p>
     */
    @QtPropertyReader(name="returnGeoValues")
    @QtUninvokable
    public final boolean returnGeoValues(){
        return returnGeoValues_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean returnGeoValues_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometer.html#returnGeoValues-prop">QMagnetometer::<wbr/>setReturnGeoValues(bool)</a></code></p>
     */
    @QtPropertyWriter(name="returnGeoValues")
    @QtUninvokable
    public final void setReturnGeoValues(boolean returnGeoValues){
        setReturnGeoValues_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), returnGeoValues);
    }
    
    @QtUninvokable
    private native void setReturnGeoValues_native_bool(long __this__nativeId, boolean returnGeoValues);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QMagnetometer(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QMagnetometer(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QMagnetometer instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QMagnetometer(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMagnetometer() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #returnGeoValues()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getReturnGeoValues() {
        return returnGeoValues();
    }
}

==> qtjambi-sensors-6.6.0-sources.jar: io/qt/sensors/QMagnetometer.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qmagnetometer.html">QMagnetometer</a></code></p>
 */
public class QMagnetometer extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMagnetometer.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometer.html#returnGeoValues-prop">QMagnetometer::<wbr>returnGeoValuesChanged(bool)</a></code></p>
     */
    @QtPropertyNotify(name="returnGeoValues")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Boolean> returnGeoValuesChanged = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometer.html#QMagnetometer">QMagnetometer::<wbr>QMagnetometer(QObject*)</a></code></p>
     */
    public QMagnetometer(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMagnetometer instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QMagnetometerReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QMagnetometerReading reading_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometer.html#returnGeoValues-prop">QMagnetometer::<wbr>returnGeoValues()const</a></code></p>
     */
    @QtPropertyReader(name="returnGeoValues")
    @QtUninvokable
    public final boolean returnGeoValues(){
        return returnGeoValues_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean returnGeoValues_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qmagnetometer.html#returnGeoValues-prop">QMagnetometer::<wbr>setReturnGeoValues(bool)</a></code></p>
     */
    @QtPropertyWriter(name="returnGeoValues")
    @QtUninvokable
    public final void setReturnGeoValues(boolean returnGeoValues){
        setReturnGeoValues_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), returnGeoValues);
    }
    
    @QtUninvokable
    private native void setReturnGeoValues_native_bool(long __this__nativeId, boolean returnGeoValues);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QMagnetometer(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QMagnetometer(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QMagnetometer instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QMagnetometer(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMagnetometer() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #returnGeoValues()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getReturnGeoValues() {
        return returnGeoValues();
    }
}
